@@ -1,13 +1,14 @@
 from __future__ import annotations
 
-from csgoinvshuffle.utils import get_depending_item_slots, get_loadout_slot_enum_value
-from csgoinvshuffle.item import Item
-from csgoinvshuffle import shuffleformat
-from csgoinvshuffle.enums import LoadoutSlot, TeamSide
+import typing as t
 from functools import cache, reduce
 from os.path import abspath
 from random import random
-import typing as t
+
+from csgoinvshuffle import shuffleformat
+from csgoinvshuffle.enums import LoadoutSlot, TeamSide
+from csgoinvshuffle.item import Item
+from csgoinvshuffle.utils import get_depending_item_slots, get_loadout_slot_enum_value
 
 
 class SlotMap(list):
@@ -61,7 +62,10 @@ class SlotMap(list):
         self, item_slot: t.Union[int, LoadoutSlot], item: t.Union[Item, str]
     ):
         if isinstance(item, Item):
+            if not item.id:
+                raise ValueError(f"Item {item} has no valid id")
             item = item.id
+
         if isinstance(item_slot, LoadoutSlot):
             item_slot = item_slot.value
         self[item_slot][1].append(item)
@@ -70,10 +74,24 @@ class SlotMap(list):
         self, item_slot: t.Union[int, LoadoutSlot], item: t.Union[Item, str]
     ) -> bool:
         if isinstance(item, Item):
+            if not item.id:
+                raise ValueError(f"Item {item} has no valid id")
             item = item.id
         if isinstance(item_slot, LoadoutSlot):
             item_slot = item_slot.value
-        return self[item_slot][1].remove(item)
+        if item in self[item_slot][1]:
+            for i in range(len(self[item_slot][1])):
+                if self[item_slot][1][-1 - i]:
+                    index = len(self[item_slot][1]) - i - 1
+                    break
+
+            self[item_slot][1].remove(item)
+
+            try:
+                return item != self[item_slot][1][index]
+            except IndexError:
+                return True
+        return False
 
     def insert(  # type: ignore
         self,
@@ -82,6 +100,8 @@ class SlotMap(list):
         item: t.Union[Item, str],
     ):
         if isinstance(item, Item):
+            if not item.id:
+                raise ValueError(f"Item {item} has no valid id")
             item = item.id
         if isinstance(item_slot, LoadoutSlot):
             item_slot = item_slot.value
@@ -148,6 +168,8 @@ class ShuffleConfig:
             return
 
         for item_slot in shuffleslots:
+            if not item.id:
+                raise ValueError(f"Item {item} has no valid id")
             self._slotmap[item_slot] = item.id
 
     def set_item(self, cycle_slot: int, item: Item, side: int = TeamSide.BOTH):
@@ -174,9 +196,8 @@ class ShuffleConfig:
         """
         Sets items starting from the cycle slot in the config
         """
-        for item in items:
-            self.set_item(cycle_slot, item, side)
-            cycle_slot += 1
+        self.set_item(cycle_slot, items[0], side)
+        self.add_items(items[1:], side)
 
     def __add_item(
         self, item: Item, shuffleslots: list[int], side: int = TeamSide.BOTH
@@ -218,7 +239,7 @@ class ShuffleConfig:
         for item_slot in shuffleslots:
             lst.append(self._slotmap.remove(item_slot, item))
 
-        return reduce(lambda x, y: x and y, lst)
+        return reduce(lambda x, y: x and y, lst, True)
 
     def remove_item(self, item: Item, side: int = TeamSide.BOTH) -> bool:
         """
@@ -302,7 +323,7 @@ class ShuffleConfig:
             if not item_ids:
                 continue
 
-            for _ in range(len(item_ids) - 1, n):
+            while len(item_ids) < n:
                 for slot in depending_itemslots:
                     index = int((len(item_ids) - 1) * random())
                     self._slotmap.append(slot, item_ids[index])
